@@ -18,13 +18,14 @@
 #
 # Program: Logger.pm
 # Author:  Timo Benk <benk@b1-systems.de>
-# Date:    Wed May 8 13:46:36 2013 +0200
-# Ident:   31a16b3e65edd6e679b461c0e27ea92a8b373c24
+# Date:    Thu May 9 08:08:32 2013 +0200
+# Ident:   03a00d9a9995d1ad059b127162589f3bdcebc8cc
 # Branch:  master
 #
 # Changelog:--reverse --grep '^tags.*relevant':-1:%an : %ai : %s
 # 
 # Timo Benk : 2013-04-28 17:27:31 +0200 : initial checkin
+# Timo Benk : 2013-05-09 07:31:52 +0200 : fix race condition in semaphore cleanup code
 #
 
 package NRun::Logger;
@@ -35,14 +36,13 @@ use warnings;
 use File::Path;
 use NRun::Semaphore;
 
-my $SEMAPHORE = NRun::Semaphore->new({key => int(rand(100000))});
-
 ###
 # create a new object.
 #
 # $_obj - parameter hash where
 # {
-#   'basedir' - the basedir the logs should be written to
+#   'basedir'   - the basedir the logs should be written to
+#   'semaphore' - the semaphore lock object
 # }
 # <- the new object
 sub new {
@@ -53,7 +53,8 @@ sub new {
     my $self = {};
     bless $self, $_pkg;
 
-    $self->{basedir} = $_obj->{basedir};
+    $self->{basedir}   = $_obj->{basedir};
+    $self->{semaphore} = $_obj->{semaphore};
 
     mkpath("$self->{basedir}/hosts");
 
@@ -76,7 +77,7 @@ sub log {
     my $_ret  = shift;
     my $_out  = shift;
 
-    $SEMAPHORE->lock();
+    $_self->{semaphore}->lock();
 
     open(RES, ">>$_self->{basedir}/results.log")
       or die("$_self->{basedir}/results.log: $!");
@@ -102,7 +103,7 @@ sub log {
     close(RES);
     close(LOG);
 
-    $SEMAPHORE->unlock();
+    $_self->{semaphore}->unlock();
 }
 
 1;
